@@ -6,6 +6,22 @@ package KUB::Manage::Document;
 
 use KUB::Document -self;
 
+sub date2els() {
+	my $date = shift;
+	return unless $date;
+	my ($sec, $min, $hour, $mday, $mon, $year, $wday, $yday, $isdst) = localtime($date);
+	return
+		[unix => $date],
+		[year => $year + 1900],
+		[month => sprintf('%02d', $mon + 1)],
+		[day => sprintf('%02d', $mday)],
+		[wday => $wday || 7],
+		[hour => sprintf('%02d', $hour)],
+		[minute => sprintf('%02d', $min)],
+		[second => sprintf('%02d', $sec)],
+	;
+}
+
 sub hash2els() {
 	my $h = shift;
 	my @res;
@@ -25,16 +41,12 @@ sub build {
 		[mode => $mode],
 		[stage => $stage],
 		[user =>
-			[uid => $req->login],
+			[uid => $req->aselect_force_login],
 			[anr => $req->anr],
 		],
+		[nonce => $req->create_nonce],
 	);
 
-	my $nonce = $req->create_nonce;
-	if(defined $nonce) {
-		$root->appendChild($self->construct(nonce => $nonce));
-	}
-
 	if(defined $req->cur_name) {
 		my $entry = $self->createElement('entry');
 		if(defined(my $name = $req->new_name)) {
@@ -53,9 +65,9 @@ sub build {
 				[destination => $_->destination],
 				[private => $_->private ? 'true' : 'false'],
 				[visits => $_->visits],
-				[ctime => $_->ctime],
-				[mtime => $_->mtime],
-				$_->atime ? [atime => $_->atime] : (),
+				[ctime => date2els($_->ctime)],
+				[mtime => date2els($_->mtime)],
+				$_->atime ? [atime => date2els($_->atime)] : (),
 			]
 		} @{$req->urls}));
 		$root->appendChild($self->construct(random => $req->random_name));
